@@ -342,7 +342,6 @@ camel_url_to_string (CamelURL *url,
                      CamelURLFlags flags)
 {
 	GString *str;
-	gchar *return_result;
 
 	g_return_val_if_fail (url != NULL, NULL);
 
@@ -390,10 +389,7 @@ camel_url_to_string (CamelURL *url,
 		append_url_encoded (str, url->fragment, NULL);
 	}
 
-	return_result = str->str;
-	g_string_free (str, FALSE);
-
-	return return_result;
+	return g_string_free (str, FALSE);
 }
 
 static void
@@ -654,7 +650,7 @@ append_url_encoded (GString *str,
  * @escape_extra: additional characters beyond " \"%#<>{}|\^[]`"
  * to escape (or %NULL)
  *
- * This %-encodes the given URL part and returns the escaped version
+ * This &percnt;-encodes the given URL part and returns the escaped version
  * in allocated memory, which the caller must free when it is done.
  *
  * Returns: the encoded string
@@ -664,23 +660,20 @@ camel_url_encode (const gchar *part,
                   const gchar *escape_extra)
 {
 	GString *str;
-	gchar *encoded;
 
 	g_return_val_if_fail (part != NULL, NULL);
 
 	str = g_string_new (NULL);
 	append_url_encoded (str, part, escape_extra);
-	encoded = str->str;
-	g_string_free (str, FALSE);
 
-	return encoded;
+	return g_string_free (str, FALSE);
 }
 
 /**
  * camel_url_decode:
  * @part: a URL part
  *
- * %-decodes the passed-in URL *in place*. The decoded version is
+ * &percnt;-decodes the passed-in URL *in place*. The decoded version is
  * never longer than the encoded version, so there does not need to
  * be any additional space at the end of the string.
  */
