@@ -29,10 +29,6 @@
 
 #include <libedataserver/e-data-server-util.h>
 
-#define E_SOURCE_BACKEND_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_SOURCE_BACKEND, ESourceBackendPrivate))
-
 struct _ESourceBackendPrivate {
 	gchar *backend_name;
 };
@@ -42,7 +38,7 @@ enum {
 	PROP_BACKEND_NAME
 };
 
-G_DEFINE_ABSTRACT_TYPE (
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (
 	ESourceBackend,
 	e_source_backend,
 	E_TYPE_SOURCE_EXTENSION)
@@ -87,7 +83,7 @@ source_backend_finalize (GObject *object)
 {
 	ESourceBackendPrivate *priv;
 
-	priv = E_SOURCE_BACKEND_GET_PRIVATE (object);
+	priv = E_SOURCE_BACKEND (object)->priv;
 
 	g_free (priv->backend_name);
 
@@ -100,8 +96,6 @@ e_source_backend_class_init (ESourceBackendClass *class)
 {
 	GObjectClass *object_class;
 
-	g_type_class_add_private (class, sizeof (ESourceBackendPrivate));
-
 	object_class = G_OBJECT_CLASS (class);
 	object_class->set_property = source_backend_set_property;
 	object_class->get_property = source_backend_get_property;
@@ -128,7 +122,7 @@ e_source_backend_class_init (ESourceBackendClass *class)
 static void
 e_source_backend_init (ESourceBackend *extension)
 {
-	extension->priv = E_SOURCE_BACKEND_GET_PRIVATE (extension);
+	extension->priv = e_source_backend_get_instance_private (extension);
 }
 
 /**
