@@ -31,7 +31,7 @@ enum {
 
 static guint signals[LAST_SIGNAL];
 
-G_DEFINE_ABSTRACT_TYPE (ECredentialsPrompterImpl, e_credentials_prompter_impl, E_TYPE_EXTENSION)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (ECredentialsPrompterImpl, e_credentials_prompter_impl, E_TYPE_EXTENSION)
 
 static void
 e_credentials_prompter_impl_constructed (GObject *object)
@@ -47,6 +47,7 @@ e_credentials_prompter_impl_constructed (GObject *object)
 	prompter = E_CREDENTIALS_PROMPTER (e_extension_get_extensible (E_EXTENSION (prompter_impl)));
 
 	klass = E_CREDENTIALS_PROMPTER_IMPL_GET_CLASS (object);
+	g_return_if_fail (klass != NULL);
 	g_return_if_fail (klass->authentication_methods != NULL);
 
 	for (ii = 0; klass->authentication_methods[ii]; ii++) {
@@ -74,8 +75,6 @@ e_credentials_prompter_impl_class_init (ECredentialsPrompterImplClass *klass)
 	GObjectClass *object_class;
 	EExtensionClass *extension_class;
 
-	g_type_class_add_private (klass, sizeof (ECredentialsPrompterImplPrivate));
-
 	object_class = G_OBJECT_CLASS (klass);
 	object_class->dispose = e_credentials_prompter_impl_dispose;
 	object_class->constructed = e_credentials_prompter_impl_constructed;
@@ -105,8 +104,7 @@ e_credentials_prompter_impl_class_init (ECredentialsPrompterImplClass *klass)
 static void
 e_credentials_prompter_impl_init (ECredentialsPrompterImpl *prompter_impl)
 {
-	prompter_impl->priv = G_TYPE_INSTANCE_GET_PRIVATE (prompter_impl,
-		E_TYPE_CREDENTIALS_PROMPTER_IMPL, ECredentialsPrompterImplPrivate);
+	prompter_impl->priv = e_credentials_prompter_impl_get_instance_private (prompter_impl);
 
 	prompter_impl->priv->cancellable = g_cancellable_new ();
 }
@@ -174,6 +172,7 @@ e_credentials_prompter_impl_prompt (ECredentialsPrompterImpl *prompter_impl,
 	g_return_if_fail (credentials != NULL);
 
 	klass = E_CREDENTIALS_PROMPTER_IMPL_GET_CLASS (prompter_impl);
+	g_return_if_fail (klass != NULL);
 	g_return_if_fail (klass->process_prompt != NULL);
 
 	klass->process_prompt (prompter_impl, prompt_id, auth_source, cred_source, error_text, credentials);
@@ -224,6 +223,7 @@ e_credentials_prompter_impl_cancel_prompt (ECredentialsPrompterImpl *prompter_im
 	g_return_if_fail (E_IS_CREDENTIALS_PROMPTER_IMPL (prompter_impl));
 
 	klass = E_CREDENTIALS_PROMPTER_IMPL_GET_CLASS (prompter_impl);
+	g_return_if_fail (klass != NULL);
 	g_return_if_fail (klass->cancel_prompt != NULL);
 
 	klass->cancel_prompt (prompter_impl, prompt_id);
