@@ -539,9 +539,6 @@ gnome_online_accounts_config_oauth (EGnomeOnlineAccounts *extension,
 	extension_name = E_SOURCE_EXTENSION_AUTHENTICATION;
 	source_extension = e_source_get_extension (source, extension_name);
 
-	e_source_authentication_set_is_external (
-		E_SOURCE_AUTHENTICATION (source_extension),
-		TRUE);
 	e_source_authentication_set_method (
 		E_SOURCE_AUTHENTICATION (source_extension),
 		CAMEL_OAUTH_MECHANISM_NAME);
@@ -561,9 +558,6 @@ gnome_online_accounts_config_oauth2 (EGnomeOnlineAccounts *extension,
 	extension_name = E_SOURCE_EXTENSION_AUTHENTICATION;
 	source_extension = e_source_get_extension (source, extension_name);
 
-	e_source_authentication_set_is_external (
-		E_SOURCE_AUTHENTICATION (source_extension),
-		TRUE);
 	e_source_authentication_set_method (
 		E_SOURCE_AUTHENTICATION (source_extension),
 		CAMEL_OAUTH2_MECHANISM_NAME);
@@ -589,6 +583,9 @@ gnome_online_accounts_config_collection (EGnomeOnlineAccounts *extension,
 		source, "display-name",
 		G_BINDING_SYNC_CREATE);
 
+	source_extension = e_source_get_extension (source, E_SOURCE_EXTENSION_AUTHENTICATION);
+	e_source_authentication_set_is_external (E_SOURCE_AUTHENTICATION (source_extension), TRUE);
+
 	extension_name = E_SOURCE_EXTENSION_GOA;
 	source_extension = e_source_get_extension (source, extension_name);
 
