@@ -18,6 +18,7 @@
 #include <locale.h>
 #include <libebook/libebook.h>
 
+#include "e-test-server-utils.h"
 #include "data-test-utils.h"
 
 static EbSqlCursorClosure ascending_closure = {
@@ -700,5 +701,5 @@ main (gint argc,
 		test_cursor_calculate_descending_after_modification,
 		e_sqlite_cursor_fixture_teardown);
 
-	return g_test_run ();
+	return e_test_server_utils_run_full (0);
 }
